//
// svg image display demo program for the Fast Light Tool Kit (FLTK).
//

#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_RGB_Image.H>

#include "nanosvg.h"
#include "nanosvgrast.h"

int main(int argc, char **argv) {

  Fl_Window *window = new Fl_Window(620,620);
  Fl_Box *box = new Fl_Box(10,10,600,600);
  box->box(FL_UP_BOX);
  window->end();

  // Parse test svg file (tiger.svg)

  NSVGimage* svg_image = 0;
  int iw = 0, ih = 0;
  svg_image = nsvgParseFromFile("tiger.svg", "px", 96);

  if (svg_image) {
    iw = int(svg_image->width);
    ih = int(svg_image->height);
    printf("size: %f x %f\n", svg_image->width, svg_image->height);
  } else {
    printf("Image not found. Exiting. :-(");
    exit(1);
  }

  // Rasterize the image

  // Create rasterizer (can be used to render multiple images).
  struct NSVGrasterizer* rast = nsvgCreateRasterizer();
  // Allocate memory for image
  unsigned char* img = (unsigned char*)malloc(iw*ih*4);
  // Rasterize
  nsvgRasterize(rast, svg_image, 180, 180, 0.60f, img, iw, ih, iw*4);

  Fl_RGB_Image *rgb = new Fl_RGB_Image(img, iw, ih, 4, 0);
  if (rgb && !rgb->fail())
    printf("Fl_RGB_Image loaded successfully\n");
  else {
    printf("Fl_RGB_Image could not be loaded, error = %d\n", rgb->fail());
    exit(2);
  }

  printf("RGB: %d x %d\n", rgb->w(), rgb->h());

  box->image(rgb);

  window->resizable(box);
  window->show(argc, argv);
  return Fl::run();
}
